@@ -1,6 +1,6 @@
 package HTML::CalendarMonth;
 {
-  $HTML::CalendarMonth::VERSION = '2.02';
+  $HTML::CalendarMonth::VERSION = '2.03';
 }
 
 use strict;
@@ -969,7 +969,7 @@ HTML::CalendarMonth - Generate and manipulate HTML calendar months
  my $c2 = HTML::CalendarMonth->new(
    month  => 8,
    year   => 2010,
-   locale => 'zu_ZA'
+   locale => 'zu-ZA'
  );
  print $c2->as_HTML;
 
@@ -1080,11 +1080,12 @@ Specifies whether to display the week-of-year numbering. Default 0.
 =item locale
 
 Specifies the id of the locale in which to render the calendar. Default
-is 'en_US'. By default, this will also control determine which day is
+is 'en-US'. By default, this will also control determine which day is
 considered to be the first day of the week. See
 L<HTML::CalendarMonth::Locale> for more information. If for some reason
 you prefer to use different labels than those provided by C<locale>, see
-the C<alias> attribute below.
+the C<alias> attribute below. NOTE: DateTime::Locale versions 0.92 and
+earlier use underscores rather than dashes, e.g. 'en_US'.
 
 =item full_days
 
@@ -1116,11 +1117,11 @@ is determined based on the locale.
 Set some handy CSS class attributes on elements, enabled by default.
 Currently the classes are:
 
-  hcm-table       Set on the <lt>table<gt> tag of the calendar
-  hcm-day-head    Set on the day-of-week <lt>tr<gt> or <lt>td<gt> tags
-  hcm-year-head   Set on the <lt>td<gt> tag for the year
-  hcm-month-head  Set on the <lt>td<gt> tag for the month
-  hcm-week-head   Set on the <lt>td<gt> tags for the week-of-year
+  hcm-table       Set on the E<lt>tableE<gt> tag of the calendar
+  hcm-day-head    Set on the day-of-week E<lt>trE<gt> or E<lt>tdE<gt> tags
+  hcm-year-head   Set on the E<lt>tdE<gt> tag for the year
+  hcm-month-head  Set on the E<lt>tdE<gt> tag for the month
+  hcm-week-head   Set on the E<lt>tdE<gt> tags for the week-of-year
 
 =item semantic_css
 
@@ -1129,9 +1130,9 @@ default. The notion of 'today' is taken either from the system clock
 (default) or from the 'today' parameter as provided to new(). Currently
 these classes are:
 
-  hcm-today    Set on the <lt>td<gt> tag for today, if present
-  hcm-past     Set on the <lt>td<gt> tags for prior days, if present
-  hcm-future   Set on the <lt>td<gt> tags for subsequent days, if present
+  hcm-today    Set on the E<lt>tdE<gt> tag for today, if present
+  hcm-past     Set on the E<lt>tdE<gt> tags for prior days, if present
+  hcm-future   Set on the E<lt>tdE<gt> tags for subsequent days, if present
 
 =item today
 
